# History

[comment]: # DEV: release-ghub-pypi scrapes Markdown from the first section below for the GitHub release.

## 2.0.0 (2020-03-29)

- API change: Rename `use_stringify` → `unmutated`.

- License: Release under MIT License.

- DX: Release and CI improvements.

## 1.0.0 (2020-01-25)

- DX: Release process improvements (no new features).

## 0.4.0 (2020-01-19)

- First official release (for [nark](https://github.com/hotoffthehamster/nark)).

